/*
              Persistence of Vision Raytracer Version 3.1
                      Gold textures

       Modified for MegaPOV 0.4 by Eric Freeman ericfree@datasync.com

The pigments are the same as in metals.inc, just renamed.
The finishes have been changed to replace specular/roughness with blinn/facets and
add reflect_metallic.
The textures have been replaced with materials to include an "interior" statement.

They may be used as-is or you may make custom materials:

#declare MyMaterial = material {
  texture {
    pigment {Whatever}     // use any pigment you like.
    finish {Mega_F_MetalA} // use any of the finishes listed below.
    normal {BlahBlahBlah}  // use any normal you like.
  }
  interior {ior 20}
}
*/
#version unofficial MegaPov 0.4;
#declare MegaMetalInt = interior {
  ior 20 // this is a guess for IOR
}

#declare Mega_GoldBase = <1.00, 0.875, 0.575>;  // mine again

// This set shifts the color toward orange by subtracting
// bluegreen from the base color.
#declare Mega_CVect1 = Mega_GoldBase  - <0.00, 0.20, 0.40>;
#declare Mega_CVect2 = Mega_GoldBase  - <0.00, 0.15, 0.30>;
#declare Mega_CVect3 = Mega_GoldBase  - <0.00, 0.10, 0.20>;
#declare Mega_CVect4 = Mega_GoldBase  - <0.00, 0.05, 0.1>;
#declare Mega_CVect5 = Mega_GoldBase  - <0.00, 0.00, 0.00>;

// Cast Mega_CVect as an rgb vector
#declare Mega_P_Gold1    = rgb Mega_CVect1;             // back row
#declare Mega_P_Gold2    = rgb Mega_CVect2;
#declare Mega_P_Gold3    = rgb Mega_CVect3;
#declare Mega_P_Gold4    = rgb Mega_CVect4;
#declare Mega_P_Gold5    = rgb Mega_CVect5;            // front row

// Reflection colors, derived from pigment color, "grayed down" a touch.
#declare Mega_R_GoldA =  Mega_P_Gold1 * 0.30 + 0.25;        // left column (soft)
#declare Mega_R_GoldB =  Mega_P_Gold2 * 0.35 + 0.25;
#declare Mega_R_GoldC =  Mega_P_Gold3 * 0.40 + 0.25;
#declare Mega_R_GoldD =  Mega_P_Gold4 * 0.45 + 0.25;
#declare Mega_R_GoldE =  Mega_P_Gold5 * 0.50 + 0.25;       // right column (hard)


// Ambient colors, derived from base color
#declare Mega_A_GoldA    =  Mega_P_Gold1 * 0.12 + 0.1;      // left column  (soft)
#declare Mega_A_GoldB    =  Mega_P_Gold2 * 0.10 + 0.1;
#declare Mega_A_GoldC    =  Mega_P_Gold3 * 0.08 + 0.1;
#declare Mega_A_GoldD    =  Mega_P_Gold4 * 0.05 + 0.1;
#declare Mega_A_GoldE    =  Mega_P_Gold5 * 0.02 + 0.1;     // right column (hard)

// Diffuse values
// Calculated as 1 - (ambient+reflective+specular values)
#declare Mega_D_GoldA    = 1-(((Mega_R_GoldA.red+Mega_R_GoldA.green+Mega_R_GoldA.blue)/3)
                       + ((Mega_A_GoldA.red+Mega_A_GoldA.green+Mega_A_GoldA.blue)/3));
#declare Mega_D_GoldB    = 1-(((Mega_R_GoldB.red+Mega_R_GoldB.green+Mega_R_GoldB.blue)/3)
                       + ((Mega_A_GoldB.red+Mega_A_GoldB.green+Mega_A_GoldB.blue)/3));
#declare Mega_D_GoldC    = 1-(((Mega_R_GoldC.red+Mega_R_GoldC.green+Mega_R_GoldC.blue)/3)
                       + ((Mega_A_GoldC.red+Mega_A_GoldC.green+Mega_A_GoldC.blue)/3));
#declare Mega_D_GoldD    = 1-(((Mega_R_GoldD.red+Mega_R_GoldD.green+Mega_R_GoldD.blue)/3)
                       + ((Mega_A_GoldD.red+Mega_A_GoldD.green+Mega_A_GoldD.blue)/3));
#declare Mega_D_GoldE    = 1-(((Mega_R_GoldE.red+Mega_R_GoldE.green+Mega_R_GoldE.blue)/3)
                       + ((Mega_A_GoldE.red+Mega_A_GoldE.green+Mega_A_GoldE.blue)/3));

#declare Mega_D_GoldA = max(Mega_D_GoldA, 0);
#declare Mega_D_GoldB = max(Mega_D_GoldB, 0);
#declare Mega_D_GoldC = max(Mega_D_GoldC, 0);
#declare Mega_D_GoldD = max(Mega_D_GoldD, 0);
#declare Mega_D_GoldE = max(Mega_D_GoldE, 0);


// #debug "\nReflection colors:"
// #debug concat("\nMega_R_GoldA=<", str(Mega_R_GoldA.red,   5, 5), "," ,
//                              str(Mega_R_GoldA.green, 5, 5),"," ,
//                              str(Mega_R_GoldA.blue,  5, 5), ">")
// #debug concat("\nMega_R_GoldB=<", str(Mega_R_GoldB.red,   5, 5), "," ,
//                              str(Mega_R_GoldB.green, 5, 5),"," ,
//                              str(Mega_R_GoldB.blue,  5, 5), ">")
// #debug concat("\nMega_R_GoldC=<", str(Mega_R_GoldC.red,   5, 5), "," ,
//                              str(Mega_R_GoldC.green, 5, 5),"," ,
//                              str(Mega_R_GoldC.blue,  5, 5), ">")
// #debug concat("\nMega_R_GoldD=<", str(Mega_R_GoldD.red,   5, 5), "," ,
//                              str(Mega_R_GoldD.green, 5, 5),"," ,
//                              str(Mega_R_GoldD.blue,  5, 5), ">")
// #debug concat("\nMega_R_GoldE=<", str(Mega_R_GoldE.red,   5, 5), "," ,
//                              str(Mega_R_GoldE.green, 5, 5),"," ,
//                              str(Mega_R_GoldE.blue,  5, 5), ">")
//
// #debug "\n\nAmbient colors:"
// #debug concat("\nMega_A_GoldA=<", str(Mega_A_GoldA.red,   5, 5), "," ,
//                              str(Mega_A_GoldA.green, 5, 5),"," ,
//                              str(Mega_A_GoldA.blue,  5, 5), ">")
// #debug concat("\nMega_A_GoldB=<", str(Mega_A_GoldB.red,   5, 5), "," ,
//                              str(Mega_A_GoldB.green, 5, 5),"," ,
//                              str(Mega_A_GoldB.blue,  5, 5), ">")
// #debug concat("\nMega_A_GoldC=<", str(Mega_A_GoldC.red,   5, 5), "," ,
//                              str(Mega_A_GoldC.green, 5, 5),"," ,
//                              str(Mega_A_GoldC.blue,  5, 5), ">")
// #debug concat("\nMega_A_GoldD=<", str(Mega_A_GoldD.red,   5, 5), "," ,
//                              str(Mega_A_GoldD.green, 5, 5),"," ,
//                              str(Mega_A_GoldD.blue,  5, 5), ">")
// #debug concat("\nMega_A_GoldE=<", str(Mega_A_GoldE.red,   5, 5), "," ,
//                              str(Mega_A_GoldE.green, 5, 5),"," ,
//                              str(Mega_A_GoldE.blue,  5, 5), ">")
//
//
// #debug "\n\nDiffuse values:"
// #debug concat("\nMega_D_GoldA = ",str(Mega_D_GoldA, 5, 5))
// #debug concat("\nMega_D_GoldB = ",str(Mega_D_GoldB, 5, 5))
// #debug concat("\nMega_D_GoldC = ",str(Mega_D_GoldC, 5, 5))
// #debug concat("\nMega_D_GoldD = ",str(Mega_D_GoldD, 5, 5))
// #debug concat("\nMega_D_GoldE = ",str(Mega_D_GoldE, 5, 5))
// #debug "\n"

#declare M = 1;    //   Metallic amount

//*****Finishes****
// Left column, dullest & darkest
#declare Mega_F_MetalA  =
finish {
    brilliance 2
    diffuse Mega_D_GoldA
    ambient Mega_A_GoldA
    reflection Mega_R_GoldA
    metallic M
    reflect_metallic
    blinn 0.6 facets 0.29
}

#declare Mega_F_MetalB  =
finish {
    brilliance 3
    diffuse Mega_D_GoldB
    ambient Mega_A_GoldB
    reflection Mega_R_GoldB
    metallic M
    reflect_metallic
    blinn 0.8 facets 0.25
}

#declare Mega_F_MetalC  =
finish {
    brilliance 4
    diffuse Mega_D_GoldC
    ambient Mega_A_GoldC
    reflection Mega_R_GoldC
    metallic M
    reflect_metallic
    blinn 1.05 facets 0.21
}

#declare Mega_F_MetalD  =
finish {
    brilliance 5
    diffuse Mega_D_GoldD
    ambient Mega_A_GoldD
    reflection Mega_R_GoldD
    metallic M
    reflect_metallic
    blinn 1.2 facets 0.16
}

#declare Mega_F_MetalE  =
finish {
    brilliance 6
    diffuse Mega_D_GoldE
    ambient Mega_A_GoldE
    reflection Mega_R_GoldE
    metallic M
    reflect_metallic
    blinn 1.3 facets 0.12
}

//                              GOLDS
#declare Mega_M_Gold_1A = material {texture {pigment {Mega_P_Gold1} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Gold_1B = material {texture {pigment {Mega_P_Gold1} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Gold_1C = material {texture {pigment {Mega_P_Gold1} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Gold_1D = material {texture {pigment {Mega_P_Gold1} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Gold_1E = material {texture {pigment {Mega_P_Gold1} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Gold_2A = material {texture {pigment {Mega_P_Gold2} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Gold_2B = material {texture {pigment {Mega_P_Gold2} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Gold_2C = material {texture {pigment {Mega_P_Gold2} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Gold_2D = material {texture {pigment {Mega_P_Gold2} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Gold_2E = material {texture {pigment {Mega_P_Gold2} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Gold_3A = material {texture {pigment {Mega_P_Gold3} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Gold_3B = material {texture {pigment {Mega_P_Gold3} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Gold_3C = material {texture {pigment {Mega_P_Gold3} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Gold_3D = material {texture {pigment {Mega_P_Gold3} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Gold_3E = material {texture {pigment {Mega_P_Gold3} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Gold_4A = material {texture {pigment {Mega_P_Gold4} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Gold_4B = material {texture {pigment {Mega_P_Gold4} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Gold_4C = material {texture {pigment {Mega_P_Gold4} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Gold_4D = material {texture {pigment {Mega_P_Gold4} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Gold_4E = material {texture {pigment {Mega_P_Gold4} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Gold_5A = material {texture {pigment {Mega_P_Gold5} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Gold_5B = material {texture {pigment {Mega_P_Gold5} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Gold_5C = material {texture {pigment {Mega_P_Gold5} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Gold_5D = material {texture {pigment {Mega_P_Gold5} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Gold_5E = material {texture {pigment {Mega_P_Gold5} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
