// Persistence of Vision Ray Tracer Scene Description File
// File: mega_m.pov
// Vers: 3.1
// Desc: test of MegaPOV metals
//       old metals on top, MegaMetals on bottom.
// Date: 13 FEB 00
// Auth: Eric L. Freeman

#version unofficial MegaPov 0.4;
#include "colors.inc"

$NormOn  = 0;  // 0=no normal  1=normal specified in DaNorm
$ObjType = 1;  // 0=box        1=sphere

$DaPig = pigment {Plum} // change this to get different colored metals.
$DaNorm = normal {wrinkles 0.25 scale 0.3}

$FSizeZ = 18;
$ObjSize = 3;
$SphDistX = ObjSize*2.3;
$SphDistZ = FSizeZ*0.7;
$CamHite = ObjSize*2.15;
// LIGHTS
light_source {
  <0,0,0>
  color White*0.7
  translate <0,CamHite,-FSizeZ>
  rotate y*65
}
light_source {
  <0,0,0>
  color White*0.7
  translate <0,CamHite,-FSizeZ>
  rotate y*-65
}

// CAMERA
$CamPos = <0,CamHite,-FSizeZ*0.99>;
$CamLook = <0,CamHite,0>;
camera {
  location CamPos
  look_at CamLook
}

$FSizeX = 125;
$Floor = box {
  <-FSizeX,-1,-FSizeZ>,
  <FSizeX,0,FSizeZ>
  pigment {
    checker
    color Green
    color Blue
    scale 3
  }
}
object { // floor
  Floor
}
object { // ceiling
  Floor
  rotate x*180
  translate <0,CamHite*2,3>
}
object { // back wall
  Floor
  translate <0,0,FSizeZ>
  rotate x*-90
  translate <0,0,FSizeZ>
}
object { // front wall
  Floor
  translate <0,0,-FSizeZ>
  rotate x*90
  translate <0,0,-FSizeZ>
}

#include "mega_metals.inc"

#if (ObjType)
  $AObject = sphere {
    <0,ObjSize,0>
    ObjSize
  }
#else
  $AObject = box {
    <-ObjSize,0,-ObjSize>,
    <ObjSize,ObjSize*2,ObjSize>
  }
#end

object {
  AObject
  material {
    texture {
      pigment {DaPig}
      finish {Mega_F_MetalA}
      #if (NormOn)
        normal {DaNorm}
      #end
    }
    interior {ior 20}
  }
  translate <-SphDistX*2,0,SphDistZ>
}
object {
  AObject
  material {
    texture {
      pigment {DaPig}
      finish {Mega_F_MetalB}
      #if (NormOn)
        normal {DaNorm}
      #end
    }
    interior {ior 20}
  }
  translate <-SphDistX,0,SphDistZ>
}
object {
  AObject
  material {
    texture {
      pigment {DaPig}
      finish {Mega_F_MetalC}
      #if (NormOn)
        normal {DaNorm}
      #end
    }
    interior {ior 20}
  }
  translate <0,0,SphDistZ>
}
object {
  AObject
  material {
    texture {
      pigment {DaPig}
      finish {Mega_F_MetalD}
      #if (NormOn)
        normal {DaNorm}
      #end
    }
    interior {ior 20}
  }
  translate <SphDistX,0,SphDistZ>
}
object {
  AObject
  material {
    texture {
      pigment {DaPig}
      finish {Mega_F_MetalE}
      #if (NormOn)
        normal {DaNorm}
      #end
    }
    interior {ior 20}
  }
  translate <SphDistX*2,0,SphDistZ>
}

//////////////// OLD TEXTURES
#version official 3.1;
#include "metals.inc"
object {
  AObject
  texture  {
    pigment {DaPig}
    finish {F_MetalA}
    #if (NormOn)
      normal {DaNorm}
    #end
  }
  translate <-SphDistX*2,SphDistX,SphDistZ>
}
object {
  AObject
  texture  {
    pigment {DaPig}
    finish {F_MetalB}
    #if (NormOn)
      normal {DaNorm}
    #end
  }
  translate <-SphDistX,SphDistX,SphDistZ>
}
object {
  AObject
  texture  {
    pigment {DaPig}
    finish {F_MetalC}
    #if (NormOn)
      normal {DaNorm}
    #end
  }
  translate <0,SphDistX,SphDistZ>
}
object {
  AObject
  texture  {
    pigment {DaPig}
    finish {F_MetalD}
    #if (NormOn)
      normal {DaNorm}
    #end
  }
  translate <SphDistX,SphDistX,SphDistZ>
}
object {
  AObject
  texture  {
    pigment {DaPig}
    finish {F_MetalE}
    #if (NormOn)
      normal {DaNorm}
    #end
  }
  translate <SphDistX*2,SphDistX,SphDistZ>
}
