/*
              Persistence of Vision Raytracer Version 3.1
               Metallic pigments, finishes, and textures.

       Modified for MegaPOV 0.4 by Eric Freeman ericfree@datasync.com

The pigments are the same as in metals.inc, just renamed.
The finishes have been changed to replace specular/roughness with blinn/facets and
add reflect_metallic.
The textures have been replaced with materials to include an "interior" statement.

They may be used as-is or you may make custom materials:

#declare MyMaterial = material {
  texture {
    pigment {Whatever}     // use any pigment you like.
    finish {Mega_F_MetalA} // use any of the finishes listed below.
    normal {BlahBlahBlah}  // use any normal you like.
  }
  interior {ior 20}
}

*****************************************************************************
                           BASIC METAL COLORS
*****************************************************************************
 Note: Describing metallic textures is difficult, at best.  The reflectivity
 and other qualities make them highly dependant on lighting and surroundings.

 The following notes are intended as a rough guide only.
 Mega_P_Brass1: Dark brown bronze.
 Mega_P_Brass2: Somewhat lighter brown than Brass4. Old penny, in soft finishes.
 Mega_P_Brass3: Used by Steve Anger's Polished_Brass. Slightly coppery.
 Mega_P_Brass4: A little yellower than Brass1.
 Mega_P_Brass5: Very light bronze, ranges from med tan to almost white.

 Mega_P_Copper1: bronze-like.  Best in finish #C.
 Mega_P_Copper2: slightly brownish copper/bronze.  Best in finishes #B-#D.
 Mega_P_Copper3: reddish-brown copper.  Best in finishes #C-#E.
 Mega_P_Copper4: pink copper, like new tubing.  Best in finishes #C-#E.
 Mega_P_Copper5: Bronze in softer finishes, gold in harder finishes.

 Mega_P_Chrome1: 20% Gray. Used in Steve Anger's Polished_Chrome.
 Mega_P_Chrome2: Slightly blueish 60% gray. Good steel w/finish #A
 Mega_P_Chrome3: 50% neutral gray.
 Mega_P_Chrome4: 75% neutral gray.
 Mega_P_Chrome5: 95% neutral gray.

 Mega_P_Silver1: Yellowish silverplate.  Somewhat tarnished looking.
 Mega_P_Silver2: Not quite as yellowish as Silver1 but more so than Silver3.
 Mega_P_Silver3: Reasonably neutral silver.
 Mega_P_Silver4: REDUNDANT (unused)
 Mega_P_Silver5: REDUNDANT (unused)

*/

#version unofficial MegaPov 0.4;
#declare MegaMetalInt = interior {
  ior 20 // this is a guess for IOR
}

#declare Mega_P_Brass1    = color rgb <0.30, 0.20, 0.10>;
#declare Mega_P_Brass2    = color rgb <0.50, 0.35, 0.25>;
#declare Mega_P_Brass3    = color rgb <0.58, 0.42, 0.20>;
#declare Mega_P_Brass4    = color rgb <0.65, 0.50, 0.25>;
#declare Mega_P_Brass5    = color rgb <0.70, 0.55, 0.40>;

#declare Mega_P_Copper1   = color rgb <0.40, 0.20, 0.15>;
#declare Mega_P_Copper2   = color rgb <0.50, 0.25, 0.15>;
#declare Mega_P_Copper3   = color rgb <0.60, 0.30, 0.15>;
#declare Mega_P_Copper4   = color rgb <0.70, 0.25, 0.15>;
#declare Mega_P_Copper5   = color rgb <0.65, 0.35, 0.15>;

#declare Mega_P_Chrome1   = color rgb <0.20, 0.20, 0.20>;
#declare Mega_P_Chrome2   = color rgb <0.39, 0.41, 0.43>;
#declare Mega_P_Chrome3   = color rgb <0.50, 0.50, 0.50>;
#declare Mega_P_Chrome4   = color rgb <0.75, 0.75, 0.75>;
#declare Mega_P_Chrome5   = color rgb <0.95, 0.95, 0.95>;

#declare Mega_P_Silver1   = color rgb <0.94, 0.93, 0.80>;
#declare Mega_P_Silver2   = color rgb <0.94, 0.93, 0.85>;
#declare Mega_P_Silver3   = color rgb <0.94, 0.93, 0.90>;
#declare Mega_P_Silver4   = color rgb <0.95, 0.91, 0.91>;             
#declare Mega_P_Silver5   = color rgb <0.91, 0.95, 0.91>;   

//*****************************************************************************
//                           BASIC METAL FINISHES
//*****************************************************************************

// Mega_F_MetalA  :  Very soft and dull.  
// Mega_F_MetalB  :  Fairly soft and dull.
// Mega_F_MetalC  :  Medium reflectivity. Holds color well.
// Mega_F_MetalD  :  Highly hard and polished. High reflectivity.   
// Mega_F_MetalE  :  Very highly polished & reflective.

#declare Mega_F_MetalA  =
finish {
    ambient 0.35
    brilliance 2
    diffuse 0.3
    metallic
    reflect_metallic
    blinn 2.0 facets 0.28
    reflection 0.15
}

#declare Mega_F_MetalB  = 
finish {
    ambient 0.30
    brilliance 3
    diffuse 0.4
    metallic
    reflect_metallic
    blinn 2.3 facets 0.24
    reflection 0.4
}

#declare Mega_F_MetalC  =
finish {
    ambient 0.25
    brilliance 4
    diffuse 0.5
    metallic
    reflect_metallic
    blinn 2.6 facets 0.20
    reflection 0.75
}

#declare Mega_F_MetalD  =
finish {
    ambient 0.15
    brilliance 5
    diffuse 0.6
    metallic
    reflect_metallic
    blinn 2.9 facets 0.16
    reflection 0.95
}

#declare Mega_F_MetalE  =
finish {
    ambient 0.1
    brilliance 6
    diffuse 0.7
    metallic
    reflect_metallic
    blinn 3.1 facets .12
    reflection 1.05
}

#declare Mega_F_MetalF  =
finish {
    ambient 0
    brilliance 6
    diffuse 0
    metallic
    reflect_metallic
    blinn 3.5 facets .09
    reflection 1.05
}

//*****************************************************************************
//                           METAL MATERIALS
//*****************************************************************************

//                              BRASSES
#declare Mega_M_Brass_1A = material {texture {pigment {Mega_P_Brass1} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Brass_1B = material {texture {pigment {Mega_P_Brass1} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Brass_1C = material {texture {pigment {Mega_P_Brass1} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Brass_1D = material {texture {pigment {Mega_P_Brass1} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Brass_1E = material {texture {pigment {Mega_P_Brass1} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Brass_2A = material {texture {pigment {Mega_P_Brass2} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Brass_2B = material {texture {pigment {Mega_P_Brass2} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Brass_2C = material {texture {pigment {Mega_P_Brass2} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Brass_2D = material {texture {pigment {Mega_P_Brass2} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Brass_2E = material {texture {pigment {Mega_P_Brass2} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Brass_3A = material {texture {pigment {Mega_P_Brass3} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Brass_3B = material {texture {pigment {Mega_P_Brass3} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Brass_3C = material {texture {pigment {Mega_P_Brass3} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Brass_3D = material {texture {pigment {Mega_P_Brass3} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Brass_3E = material {texture {pigment {Mega_P_Brass3} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Brass_4A = material {texture {pigment {Mega_P_Brass4} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Brass_4B = material {texture {pigment {Mega_P_Brass4} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Brass_4C = material {texture {pigment {Mega_P_Brass4} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Brass_4D = material {texture {pigment {Mega_P_Brass4} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Brass_4E = material {texture {pigment {Mega_P_Brass4} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Brass_5A = material {texture {pigment {Mega_P_Brass5} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Brass_5B = material {texture {pigment {Mega_P_Brass5} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Brass_5C = material {texture {pigment {Mega_P_Brass5} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Brass_5D = material {texture {pigment {Mega_P_Brass5} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Brass_5E = material {texture {pigment {Mega_P_Brass5} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

//                           COPPERS & BRONZES
#declare Mega_M_Copper_1A = material {texture {pigment {Mega_P_Copper1} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Copper_1B = material {texture {pigment {Mega_P_Copper1} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Copper_1C = material {texture {pigment {Mega_P_Copper1} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Copper_1D = material {texture {pigment {Mega_P_Copper1} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Copper_1E = material {texture {pigment {Mega_P_Copper1} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Copper_2A = material {texture {pigment {Mega_P_Copper2} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Copper_2B = material {texture {pigment {Mega_P_Copper2} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Copper_2C = material {texture {pigment {Mega_P_Copper2} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Copper_2D = material {texture {pigment {Mega_P_Copper2} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Copper_2E = material {texture {pigment {Mega_P_Copper2} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Copper_3A = material {texture {pigment {Mega_P_Copper3} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Copper_3B = material {texture {pigment {Mega_P_Copper3} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Copper_3C = material {texture {pigment {Mega_P_Copper3} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Copper_3D = material {texture {pigment {Mega_P_Copper3} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Copper_3E = material {texture {pigment {Mega_P_Copper3} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Copper_4A = material {texture {pigment {Mega_P_Copper4} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Copper_4B = material {texture {pigment {Mega_P_Copper4} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Copper_4C = material {texture {pigment {Mega_P_Copper4} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Copper_4D = material {texture {pigment {Mega_P_Copper4} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Copper_4E = material {texture {pigment {Mega_P_Copper4} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Copper_5A = material {texture {pigment {Mega_P_Copper5} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Copper_5B = material {texture {pigment {Mega_P_Copper5} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Copper_5C = material {texture {pigment {Mega_P_Copper5} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Copper_5D = material {texture {pigment {Mega_P_Copper5} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Copper_5E = material {texture {pigment {Mega_P_Copper5} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

//                           CHROMES & STEELS  
#declare Mega_M_Chrome_1A = material {texture {pigment {Mega_P_Chrome1} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_1B = material {texture {pigment {Mega_P_Chrome1} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_1C = material {texture {pigment {Mega_P_Chrome1} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_1D = material {texture {pigment {Mega_P_Chrome1} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_1E = material {texture {pigment {Mega_P_Chrome1} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Chrome_2A = material {texture {pigment {Mega_P_Chrome2} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_2B = material {texture {pigment {Mega_P_Chrome2} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_2C = material {texture {pigment {Mega_P_Chrome2} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_2D = material {texture {pigment {Mega_P_Chrome2} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_2E = material {texture {pigment {Mega_P_Chrome2} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Chrome_3A = material {texture {pigment {Mega_P_Chrome3} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_3B = material {texture {pigment {Mega_P_Chrome3} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_3C = material {texture {pigment {Mega_P_Chrome3} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_3D = material {texture {pigment {Mega_P_Chrome3} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_3E = material {texture {pigment {Mega_P_Chrome3} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Chrome_4A = material {texture {pigment {Mega_P_Chrome4} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_4B = material {texture {pigment {Mega_P_Chrome4} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_4C = material {texture {pigment {Mega_P_Chrome4} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_4D = material {texture {pigment {Mega_P_Chrome4} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_4E = material {texture {pigment {Mega_P_Chrome4} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Chrome_5A = material {texture {pigment {Mega_P_Chrome5} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_5B = material {texture {pigment {Mega_P_Chrome5} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_5C = material {texture {pigment {Mega_P_Chrome5} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_5D = material {texture {pigment {Mega_P_Chrome5} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Chrome_5E = material {texture {pigment {Mega_P_Chrome5} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

//                               SILVERS        
#declare Mega_M_Silver_1A = material {texture {pigment {Mega_P_Silver1} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Silver_1B = material {texture {pigment {Mega_P_Silver1} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Silver_1C = material {texture {pigment {Mega_P_Silver1} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Silver_1D = material {texture {pigment {Mega_P_Silver1} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Silver_1E = material {texture {pigment {Mega_P_Silver1} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Silver_2A = material {texture {pigment {Mega_P_Silver2} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Silver_2B = material {texture {pigment {Mega_P_Silver2} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Silver_2C = material {texture {pigment {Mega_P_Silver2} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Silver_2D = material {texture {pigment {Mega_P_Silver2} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Silver_2E = material {texture {pigment {Mega_P_Silver2} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Silver_3A = material {texture {pigment {Mega_P_Silver3} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Silver_3B = material {texture {pigment {Mega_P_Silver3} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Silver_3C = material {texture {pigment {Mega_P_Silver3} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Silver_3D = material {texture {pigment {Mega_P_Silver3} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Silver_3E = material {texture {pigment {Mega_P_Silver3} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
                                           
#declare Mega_M_Silver_4A = material {texture {pigment {Mega_P_Silver4} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Silver_4B = material {texture {pigment {Mega_P_Silver4} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Silver_4C = material {texture {pigment {Mega_P_Silver4} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Silver_4D = material {texture {pigment {Mega_P_Silver4} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Silver_4E = material {texture {pigment {Mega_P_Silver4} finish {Mega_F_MetalE}} interior {MegaMetalInt}}

#declare Mega_M_Silver_5A = material {texture {pigment {Mega_P_Silver5} finish {Mega_F_MetalA}} interior {MegaMetalInt}}
#declare Mega_M_Silver_5B = material {texture {pigment {Mega_P_Silver5} finish {Mega_F_MetalB}} interior {MegaMetalInt}}
#declare Mega_M_Silver_5C = material {texture {pigment {Mega_P_Silver5} finish {Mega_F_MetalC}} interior {MegaMetalInt}}
#declare Mega_M_Silver_5D = material {texture {pigment {Mega_P_Silver5} finish {Mega_F_MetalD}} interior {MegaMetalInt}}
#declare Mega_M_Silver_5E = material {texture {pigment {Mega_P_Silver5} finish {Mega_F_MetalE}} interior {MegaMetalInt}}
