// Persistence of Vision Ray Tracer Scene Description File
// File: mega_metal_demo.pov
// Vers: 3.1 MegaPatch 0.4
// Desc: Demo of Blinn Highlight Metal Includes
// Date: 02 FEB 00
// Auth: Eric L. Freeman

#include "colors.inc"

// LIGHTS
light_source {
  <0,0,0>
  color White
  translate <0,0,-42>
  rotate x*55
  rotate y*55
}
light_source {
  <0,0,0>
  color White*0.7
  translate <0,0,-39>
  rotate x*20
  rotate y*-25
}

// CAMERA
#declare CamPos = <4,30,-39>;
#declare CamLook = <0,20,0>;
camera {
  location CamPos
  look_at CamLook
  angle 73
/*
// focal blur extras below
  aperture 0.2          // 0...N (bigger is narrower depth of field)
  blur_samples 4        // # of rays per pixel (100-1000)
  confidence 0.9999     // more 9's the better... min of 4
  focal_point <VECTOR>  // x,y,z point that is in focus
*/
}

// FLOOR, CEILING AND WALLS
#declare WallX = 40;
#declare PigSc = 6;
#declare Amb = 0.25;

// OBJECTS
#include "metals.inc"

box { // front wall
  <-WallX,0,WallX>,
  <WallX,WallX,WallX+1>
  pigment {checker color DarkPurple color SpringGreen scale PigSc}
  finish {ambient Amb}
}
box { // back wall
  <-WallX,0,-WallX>,
  <WallX,WallX,-WallX-1>
  pigment {checker color NeonPink color NewMidnightBlue scale PigSc}
  finish {ambient Amb}
}
box { // rite wall
  <WallX,0,-WallX>,
  <WallX+1,WallX,WallX>
  pigment {checker color Scarlet color HuntersGreen scale PigSc}
  finish {ambient Amb}
}
box { // floor
  <-WallX,-1,-WallX>,
  <WallX,0,WallX>
  pigment {checker color Blue color Quartz scale PigSc}
  finish {ambient Amb}
}
box { // ceiling
  <-WallX,WallX,-WallX>,
  <WallX,WallX+1,WallX>
  pigment {checker color Green color Very_Light_Purple scale PigSc}
  finish {ambient Amb}
}
box { // left wall
  <-WallX-1,0,-WallX>,
  <-WallX,WallX,WallX>
  pigment {checker color Blue color Turquoise scale PigSc}
  finish {ambient Amb}
}



cylinder {
  <-18,0,-9>,
  <-18,25,-9>
  4
  texture {T_Brass_3C}
  normal {agate 1}
}

sphere {
  <0,11,0>,
  10
  texture {T_Silver_3D}
}

sphere {
  <8,19,-11>,
  2.5
  texture {T_Copper_4D}
}

torus {
  8,2.5
  sturm
  texture {T_Gold_4B}
  rotate <57,36,0>
  translate <19,23,8>
}

box {
  <-6,0,-6>,
  <6,12,6>
  texture {T_Copper_3E}
  rotate <24,37,7>
  translate <-21,20,17>
}

box {
  <-4,0,-10>,
  <35,0.1,25>
  pigment {SeaGreen}
  finish {F_MetalE}
}

box {
  <-38,14,40>,
  <38,28,39.9>
  pigment {Orchid}
  finish {F_MetalD}
}

